@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "elfeed" "3.4.2"
+(define-package "elfeed" "20241202.22"
   "An Emacs Atom/RSS feed reader."
   '((emacs "24.3"))
   :url "https://github.com/skeeto/elfeed"
-  :commit "904b6d4feca78e7e5336d7dbb7b8ba53b8c4dac1"
-  :revdesc "3.4.2-0-g904b6d4feca7"
+  :commit "a39fb78e34ee25dc8baea83376f929d7c128344f"
+  :revdesc "a39fb78e34ee"
   :authors '(("Christopher Wellons" . "wellons@nullprogram.com"))
   :maintainers '(("Christopher Wellons" . "wellons@nullprogram.com")))
